@@ -132,6 +132,45 @@ class VirtualMedia(base.ResourceBase):
             return True
         return False
 
+    def is_credentials_required(self, error=None):
+        """Check the response code and body and in case of failure
+
+        Try to determine if it happened due to missing Credentials
+        """
+
+        # Accept broader variants seen on NVIDIA DGX where "code" may be absent
+        try:
+            body = error.response.json()
+        except Exception:
+            body = {}
+
+        # Structured path: @Message.ExtendedInfo entries
+        ext = (body.get('error', {}) or {}).get('@Message.ExtendedInfo',
+                                                []) or []
+        for m in ext:
+            mid = (m.get('MessageId') or '')
+            msg = (m.get('Message') or '')
+            if mid.endswith('ActionParameterMissing') and (
+                'UserName' in msg or 'Password' in msg):
+                return True
+
+        # Legacy/structured: error.code + message mentions UserName/Password
+        err_obj = (body.get('error') or {})
+        code = (err_obj.get('code') or '')
+        msg = (err_obj.get('message') or '')
+        if code.endswith('GeneralError') and (
+            'UserName' in msg or 'Password' in msg
+                or 'parameter missing' in msg):
+            return True
+
+        # Text fallback: common strings observed in the field
+        raw_msg = ((body.get('error') or {}).get('message') or '') + ' ' + (
+            error.detail or '')
+        if ('requires the parameter UserName' in raw_msg
+                or 'requires the parameter Password' in raw_msg):
+            return True
+        return False
+
     def insert_media(self, image, inserted=True, write_protected=True,
                      username=None, password=None, transfer_method=None):
         """Attach remote media to virtual media
@@ -249,8 +288,10 @@ class VirtualMedia(base.ResourceBase):
                 parameter='verify_certificate', value=verify_certificate,
                 valid_values='boolean (True, False)')
 
+        etag = self._get_etag()
         self._conn.patch(self.path,
-                         data={'VerifyCertificate': verify_certificate})
+                         data={'VerifyCertificate': verify_certificate},
+                         etag=etag)
         self.invalidate()
 
     @property
